package com.fireworksdk.bridge.flutter.handler

import android.view.ViewGroup
import android.widget.FrameLayout
import androidx.fragment.app.FragmentActivity
import com.fireworksdk.bridge.components.storyblock.StoryBlockFrameLayout
import com.fireworksdk.bridge.flutter.models.FWStoryBlockCallMethod
import com.fireworksdk.bridge.utils.FWCommonUtil
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel


class FWStoryBlockHandler(
  private val activity: FragmentActivity,
  private val storyBlockFrameLayout: StoryBlockFrameLayout,
) : MethodChannel.MethodCallHandler {

  private var handleResult: MethodChannel.Result? = null

  override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
    handleResult = result

    when (call.method) {
      FWStoryBlockCallMethod.Play.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.play()
        result.success(null)
      }
      FWStoryBlockCallMethod.Pause.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.pause()
        result.success(null)
      }
      FWStoryBlockCallMethod.OpenFullscreen.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.openFullscreen()
        result.success(null)
      }

      FWStoryBlockCallMethod.SetMarginRight.rawValue -> {
        val right: Double = call.arguments as Double
        val layoutParams = FrameLayout.LayoutParams(
          ViewGroup.LayoutParams.MATCH_PARENT,
          ViewGroup.LayoutParams.MATCH_PARENT
        )
        layoutParams.setMargins(0, 0, FWCommonUtil.dpToPx(right.toFloat(), activity), 0)
        storyBlockFrameLayout.storyBlockFragment?.setStoryBlockLayoutParams(layoutParams)
        result.success(null)
      }

      FWStoryBlockCallMethod.SetStoryBlockConfiguration.rawValue -> {
        result.success(null)
      }

      FWStoryBlockCallMethod.ShowIvsPlayerView.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.showIvsPlayerView()
        result.success(null)
      }

      FWStoryBlockCallMethod.HideIvsPlayerView.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.hideIvsPlayerView()
        result.success(null)
      }

      FWStoryBlockCallMethod.RemoveIvsPlayerView.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.removeIvsPlayerView()
        result.success(null)
      }

      FWStoryBlockCallMethod.PlayIvsPlayer.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.playIvsPlayer()
        result.success(null)
      }

      FWStoryBlockCallMethod.PauseIvsPlayer.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.pauseIvsPlayer()
        result.success(null)
      }

      FWStoryBlockCallMethod.OnViewportEntered.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.onViewportEntered()
        result.success(null)
      }

      FWStoryBlockCallMethod.OnViewportLeft.rawValue -> {
        storyBlockFrameLayout.storyBlockFragment?.onViewportLeft()
        result.success(null)
      }

      else -> {
        result.notImplemented()
      }
    }
  }

  private fun hideStoryBlockFragment() {
    storyBlockFrameLayout.storyBlockFragment?.let {
      val fm = activity.supportFragmentManager
      fm.beginTransaction().hide(it).commit()
    }
  }

  private fun showStoryBlockFragment() {
    storyBlockFrameLayout.storyBlockFragment?.let {
      val fm = activity.supportFragmentManager
      fm.beginTransaction().show(it).commit()
    }
  }
}