package com.fireworksdk.bridge.models

import com.fireworksdk.bridge.models.enums.FWCtaButtonTextValue
import com.fireworksdk.bridge.models.enums.FWProductCardCtaButtonTextValue
import com.fireworksdk.bridge.models.enums.FWProductCardTheme
import org.json.JSONObject

object FWProductInfoViewConfigurationDeserializer {

  private const val CTA_BUTTON_KEY = "ctaButton"
  private const val LINK_BUTTON_KEY = "linkButton"
  private const val PRODUCT_CARD_KEY = "productCard"

  private const val TEXT_KEY = "text"
  private const val BACKGROUND_COLOR_KEY = "backgroundColor"
  private const val TEXT_COLOR_KEY = "textColor"
  private const val FONT_SIZE_KEY = "fontSize"

  private const val IS_HIDDEN_KEY = "isHidden"

  private const val CTA_BUTTON_TEXT_KEY = "ctaButtonText"
  private const val THEME_KEY = "theme"
  private const val CORNER_RADIUS_KEY = "cornerRadius"
  private const val PRICE_CONFIGURATION_KEY = "priceConfiguration"
  private const val IS_CTA_BUTTON_HIDDEN_KEY = "isCtaButtonHidden"

  fun deserialize(responseJson: JSONObject?): FWProductInfoViewConfiguration? {
    responseJson ?: return null

    val ctaButtonConfiguration = deserializeCtaButtonConfiguration(responseJson.optJSONObject(CTA_BUTTON_KEY))
    val linkButtonConfiguration = deserializeLinkButtonConfiguration(responseJson.optJSONObject(LINK_BUTTON_KEY))
    val productCardConfiguration = deserializeProductCardConfiguration(responseJson.optJSONObject(PRODUCT_CARD_KEY))

    return FWProductInfoViewConfiguration(
      ctaButton = ctaButtonConfiguration,
      linkButton = linkButtonConfiguration,
      productCard = productCardConfiguration,
    )
  }

  private fun deserializeCtaButtonConfiguration(ctaButtonConfiguration: JSONObject?): FWProductInfoViewConfiguration.CtaButtonConfiguration {
    ctaButtonConfiguration ?: return FWProductInfoViewConfiguration.CtaButtonConfiguration()

    val textString = if (ctaButtonConfiguration.has(TEXT_KEY)) ctaButtonConfiguration.optString(TEXT_KEY) else null
    val backgroundColor = if (ctaButtonConfiguration.has(BACKGROUND_COLOR_KEY)) ctaButtonConfiguration.optString(BACKGROUND_COLOR_KEY) else null
    val textColor = if (ctaButtonConfiguration.has(TEXT_COLOR_KEY)) ctaButtonConfiguration.optString(TEXT_COLOR_KEY) else null
    val fontSize = if (ctaButtonConfiguration.has(FONT_SIZE_KEY)) ctaButtonConfiguration.optInt(FONT_SIZE_KEY) else null

    return FWProductInfoViewConfiguration.CtaButtonConfiguration(
      text = FWCtaButtonTextValue.deserialize(textString),
      backgroundColor = backgroundColor,
      textColor = textColor,
      fontSize = fontSize,
    )
  }

  private fun deserializeLinkButtonConfiguration(linkButtonConfigJson: JSONObject?): FWProductInfoViewConfiguration.LinkButtonConfiguration {
    linkButtonConfigJson ?: return FWProductInfoViewConfiguration.LinkButtonConfiguration()

    val isHidden = if (linkButtonConfigJson.has(IS_HIDDEN_KEY)) linkButtonConfigJson.optBoolean(IS_HIDDEN_KEY) else null

    return FWProductInfoViewConfiguration.LinkButtonConfiguration(
      isHidden = isHidden,
    )
  }

  private fun deserializeProductCardConfiguration(productCardConfigJson: JSONObject?): FWProductInfoViewConfiguration.ProductCardConfiguration {
    productCardConfigJson ?: return FWProductInfoViewConfiguration.ProductCardConfiguration()

    val ctaButtonTextString = if (productCardConfigJson.has(CTA_BUTTON_TEXT_KEY)) productCardConfigJson.optString(CTA_BUTTON_TEXT_KEY) else null
    val themeString = if (productCardConfigJson.has(THEME_KEY)) productCardConfigJson.optString(THEME_KEY) else null
    val cornerRadius = if (productCardConfigJson.has(CORNER_RADIUS_KEY)) productCardConfigJson.optInt(CORNER_RADIUS_KEY) else null
    val priceConfiguration = deserializeProductCardPriceConfiguration(productCardConfigJson.optJSONObject(PRICE_CONFIGURATION_KEY))
    val isCtaButtonHidden = if (productCardConfigJson.has(IS_CTA_BUTTON_HIDDEN_KEY)) productCardConfigJson.optBoolean(IS_CTA_BUTTON_HIDDEN_KEY) else null

    return FWProductInfoViewConfiguration.ProductCardConfiguration(
      ctaButtonText = FWProductCardCtaButtonTextValue.deserialize(ctaButtonTextString),
      theme = FWProductCardTheme.deserialize(themeString),
      cornerRadius = cornerRadius,
      priceConfiguration = priceConfiguration,
      isCtaButtonHidden = isCtaButtonHidden,
    )
  }

  private fun deserializeProductCardPriceConfiguration(productCardPriceConfigurationJson: JSONObject?): FWProductInfoViewConfiguration.ProductCardPriceConfiguration {
    productCardPriceConfigurationJson ?: return FWProductInfoViewConfiguration.ProductCardPriceConfiguration()
    val isHidden = if (productCardPriceConfigurationJson.has(IS_HIDDEN_KEY)) productCardPriceConfigurationJson.optBoolean(IS_HIDDEN_KEY) else null

    return FWProductInfoViewConfiguration.ProductCardPriceConfiguration(
      isHidden = isHidden,
    )
  }
}
