package com.fireworksdk.bridge.models

import com.fireworksdk.bridge.models.enums.FWCtaButtonTextValue
import org.json.JSONObject

object FWProductInfoViewConfigurationSerializer {

  private const val CTA_BUTTON_KEY = "ctaButton"
  private const val LINK_BUTTON_KEY = "linkButton"
  private const val PRODUCT_CARD_KEY = "productCard"

  private const val TEXT_KEY = "text"
  private const val BACKGROUND_COLOR_KEY = "backgroundColor"
  private const val TEXT_COLOR_KEY = "textColor"
  private const val FONT_SIZE_KEY = "fontSize"

  private const val IS_HIDDEN_KEY = "isHidden"

  private const val CTA_BUTTON_TEXT_KEY = "ctaButtonText"
  private const val THEME_KEY = "theme"
  private const val CORNER_RADIUS_KEY = "cornerRadius"
  private const val PRICE_CONFIGURATION_KEY = "priceConfiguration"
  private const val IS_CTA_BUTTON_HIDDEN_KEY = "isCtaButtonHidden"

  fun serialize(model: FWProductInfoViewConfiguration?): JSONObject? {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(CTA_BUTTON_KEY, serializeCtaButtonConfiguration(model.ctaButton))
    jsonObject.put(LINK_BUTTON_KEY, serializeLinkButtonConfiguration(model.linkButton))
    jsonObject.put(PRODUCT_CARD_KEY, serializeProductCardConfiguration(model.productCard))
    return jsonObject
  }

  private fun serializeCtaButtonConfiguration(model: FWProductInfoViewConfiguration.CtaButtonConfiguration?): JSONObject? {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(TEXT_KEY, FWCtaButtonTextValue.serialize(model.text))
    jsonObject.put(BACKGROUND_COLOR_KEY, model.backgroundColor)
    jsonObject.put(TEXT_COLOR_KEY, model.textColor)
    jsonObject.put(FONT_SIZE_KEY, model.fontSize)
    return jsonObject
  }

  private fun serializeLinkButtonConfiguration(model: FWProductInfoViewConfiguration.LinkButtonConfiguration?): JSONObject? {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(IS_HIDDEN_KEY, model.isHidden)
    return jsonObject
  }

  private fun serializeProductCardConfiguration(model: FWProductInfoViewConfiguration.ProductCardConfiguration?): JSONObject? {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(CTA_BUTTON_TEXT_KEY, model.ctaButtonText)
    jsonObject.put(THEME_KEY, model.theme)
    jsonObject.put(CORNER_RADIUS_KEY, model.cornerRadius)
    jsonObject.put(PRICE_CONFIGURATION_KEY, serializeProductCardPriceConfiguration(model.priceConfiguration))
    jsonObject.put(IS_CTA_BUTTON_HIDDEN_KEY, model.isCtaButtonHidden)
    return jsonObject
  }

  private fun serializeProductCardPriceConfiguration(model: FWProductInfoViewConfiguration.ProductCardPriceConfiguration?): JSONObject? {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(IS_HIDDEN_KEY, model.isHidden)
    return jsonObject
  }
}