package com.fireworksdk.bridge.models

import com.fireworksdk.bridge.models.enums.FWCtaDelayType
import com.fireworksdk.bridge.models.enums.FWPlayerStyle
import com.fireworksdk.bridge.models.enums.FWVideoCompleteAction
import com.fireworksdk.bridge.models.enums.FWVideoPlayerCTAWidth
import org.json.JSONObject

object FWVideoPlayerConfigModelSerializer {

  private const val PLAYER_STYLE_KEY = "playerStyle"
  private const val VIDEO_COMPLETE_ACTION_KEY = "videoCompleteAction"
  private const val SHOW_SHARE_BUTTON_KEY = "showShareButton"
  private const val CTA_BUTTON_STYLE_KEY = "ctaButtonStyle"
  private const val SHOW_MUTE_BUTTON_KEY = "showMuteButton"
  private const val SHOW_PLAYBACK_BUTTON_KEY = "showPlaybackButton"
  private const val SHOW_BRANDING_KEY = "showBranding"
  private const val CTA_DELAY_KEY = "ctaDelay"
  private const val CTA_HIGHLIGHT_DELAY_KEY = "ctaHighlightDelay"
  private const val SHARE_BASE_URL_KEY = "shareBaseURL"
  private const val CTA_WIDTH_KEY = "ctaWidth"
  private const val ENABLE_PIP_KEY = "enablePictureInPicture"
  private const val SHOW_VIDEO_DETAIL_TITLE_KEY = "showVideoDetailTitle"
  private const val BUTTON_CONFIGURATION_KEY = "buttonConfiguration"

  private const val BACKGROUND_COLOR_KEY = "backgroundColor"
  private const val FONT_SIZE_KEY = "fontSize"
  private const val TEXT_COLOR_KEY = "textColor"

  private const val TYPE_KEY = "type"
  private const val VALUE_KEY = "value"

  fun serialize(model: FWVideoPlayerConfigModel?): JSONObject? {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(PLAYER_STYLE_KEY, FWPlayerStyle.serialize(model.playerStyle))
    jsonObject.put(VIDEO_COMPLETE_ACTION_KEY, FWVideoCompleteAction.serialize(model.videoCompleteAction))
    jsonObject.put(SHOW_SHARE_BUTTON_KEY, model.showShareButton)
    jsonObject.put(CTA_BUTTON_STYLE_KEY, serializeCtaButtonStyle(model.ctaButtonStyle))
    jsonObject.put(SHOW_MUTE_BUTTON_KEY, model.showMuteButton)
    jsonObject.put(SHOW_PLAYBACK_BUTTON_KEY, model.showPlaybackButton)
    jsonObject.put(SHOW_BRANDING_KEY, model.showBranding)
    jsonObject.put(CTA_DELAY_KEY, serializeCtaDelay(model.ctaDelay))
    jsonObject.put(CTA_HIGHLIGHT_DELAY_KEY, serializeCtaDelay(model.ctaHighlightDelay))
    jsonObject.put(SHARE_BASE_URL_KEY, model.shareBaseUrl)
    jsonObject.put(CTA_WIDTH_KEY, FWVideoPlayerCTAWidth.serialize(model.ctaWidth))
    jsonObject.put(ENABLE_PIP_KEY, model.enablePictureInPicture)
    jsonObject.put(SHOW_VIDEO_DETAIL_TITLE_KEY, model.showVideoDetailTitle)
    jsonObject.put(BUTTON_CONFIGURATION_KEY, FWPlayerButtonConfigurationSerializer.serialize(model.buttonConfiguration))
    return jsonObject
  }

  private fun serializeCtaButtonStyle(model: FWVideoPlayerConfigModel.FWCtaButtonStyleModel?): JSONObject? {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(BACKGROUND_COLOR_KEY, model.backgroundColor)
    jsonObject.put(FONT_SIZE_KEY, model.fontSize)
    jsonObject.put(TEXT_COLOR_KEY, model.textColor)
    return jsonObject
  }

  private fun serializeCtaDelay(model: FWVideoPlayerConfigModel.FWCtaDelayModel?): JSONObject? {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(TYPE_KEY, FWCtaDelayType.serialize(model.type))
    jsonObject.put(VALUE_KEY, model.value)
    return jsonObject
  }
}