//
//  Convert+FireworkSdk.swift
//  fw_flutter_sdk
//
//  Created by Jeff on 2021/12/20.
//

import FireworkVideo
import Foundation
import UIKit

extension Convert {
    static func videoPlayerContentConfiguration(_ config: [String: AnyObject]?)
        -> VideoPlayerContentConfiguration? {
        guard let config = config else {
            return nil
        }

        let playerViewConfig = JsonHelper.fromDictionary(config, type: VideoPlayerConfiguration.self)

        let finalConfig = VideoFeed.convertToVideoPlayerContentConfiguration(playerViewConfig)

        return finalConfig
    }

    static func videoPlayerStyle(_ style: String?) -> VideoPlayerContentConfiguration
        .VideoPlayerStyle? {
        guard let rStyle = style else {
            return nil
        }
        if rStyle == "fit" {
            return .fit
        } else {
            return .fullBleed
        }
    }

    static func videoCompleteAction(_ action: String?) -> VideoPlayerContentConfiguration
        .VideoCompleteAction? {
        guard let action = action else {
            return nil
        }
        if action == "loop" {
            return .loop
        } else {
            return .advanceToNext
        }
    }

    static func ctaButtonStyle(_ style: [String: AnyObject]?) -> ButtonContentConfiguration? {
        guard let rStyle = style else {
            return nil
        }
        var btnContentConfig = ButtonContentConfiguration()
        if let backgroundColor = rStyle["backgroundColor"] as? String, let color = backgroundColor.uicolor() {
            btnContentConfig.backgroundColor = color
        }
        if let textColor = rStyle["textColor"] as? String, let color = textColor.uicolor() {
            btnContentConfig.textColor = color
        }
        if let fontSize = rStyle["fontSize"] as? Double {
            btnContentConfig.font = UIFont.systemFont(ofSize: fontSize)
        }

        return btnContentConfig
    }

    static func sdkInitOptions(_ options: [String: AnyObject]?) -> SDKInitOptions? {
        guard let rOptions = options else {
            return nil
        }

        let jsonData = try? JSONSerialization.data(withJSONObject: rOptions, options: .prettyPrinted)
        guard let rJsonData = jsonData else {
            return nil
        }

        var result: SDKInitOptions?
        do {
            result = try JSONDecoder().decode(SDKInitOptions.self, from: rJsonData)
        } catch let error {
            print(error.localizedDescription)
        }

        return result
    }
}
