//
//  Convert+FWVideoFeed.swift
//  fw_flutter_sdk
//
//  Created by Jeff Zheng on 2021/12/22.
//

import FireworkVideo
import Foundation

extension VideFeedSourceType {
    static var sourceTypeMapper: [String: VideFeedSourceType] {
        [
            "discover": .discover,
            "channel": .channel,
            "playlist": .playlist,
            "playlistGroup": .playlistGroup,
            "dynamicContent": .dynamicContent,
            "hashtagPlaylist": .hashtagPlaylist,
            "sku": .sku,
            "singleContent": .singleContent
        ]
    }
}

extension VideoFeedMode {
    static var feedModeMapper: [String: VideoFeedMode] {
        [
            "row": .row,
            "column": .column,
            "grid": .grid
        ]
    }
}

extension Convert {
    static func videoFeedSourceType(_ type: String?) -> VideFeedSourceType {
        guard let rType = type else {
            return .discover
        }

        return VideFeedSourceType.sourceTypeMapper[rType] ?? .discover
    }

    static func videoFeedMode(_ type: String?) -> VideoFeedMode {
        guard let rType = type else {
            return .row
        }

        return VideoFeedMode.feedModeMapper[rType] ?? .row
    }

    static func getFireworkVideoAdConfiguration(
        _ adConfiguration: AdConfiguration?
    ) -> FireworkVideo.AdConfiguration? {
        guard let feedAdConfiguration = adConfiguration else {
            return nil
        }

        var resultAdConfiguration = FireworkVideo.AdConfiguration()
        if let requiresAds = feedAdConfiguration.requiresAds {
            resultAdConfiguration.requiresAds = requiresAds
        }

        if let adsFetchTimeout = feedAdConfiguration.adsFetchTimeout {
            resultAdConfiguration.adsFetchTimeout = adsFetchTimeout
        }

        if let vastAttributes = feedAdConfiguration.vastAttributes {
            resultAdConfiguration.vastAttributes = vastAttributes.map({ attribute in
                return URLQueryItem(name: attribute.name ?? "", value: attribute.value ?? "")
            })
        }

        return resultAdConfiguration
    }
}
