import 'models/method_names.dart';
import './utils/fw_method_channel_util.dart';

/// You can use this class for pushing Flutter page from the native page.
class FWNavigator {
  static FWNavigator? _instance;

  static FWNavigator _getInstance() {
    _instance ??= FWNavigator._();
    return _instance!;
  }

  FWNavigator._();

  factory FWNavigator.getInstance() => _getInstance();

  /// Pop the native container. You could use the method to close the fullscreen player.
  /// But if the enablePictureInPicture of the associated video feed is true,
  /// we can't close the fullscreen player.
  Future<bool> popNativeContainer() async {
    final result =
        await FWMethodChannelUtil.getNavigatorMethodChannel().invokeMethod(
      NavigatorNativeMethodName.popNativeContainer.name,
    );
    return result;
  }

  /// Change current fullscreen player to floating player.
  Future<bool> startFloatingPlayer() async {
    final result =
        await FWMethodChannelUtil.getNavigatorMethodChannel().invokeMethod(
      NavigatorNativeMethodName.startFloatingPlayer.name,
    );
    return result;
  }

  /// Change current fullscreen player to floating player.
  Future<void> stopFloatingPlayer() async {
    final result =
        await FWMethodChannelUtil.getNavigatorMethodChannel().invokeMethod(
      NavigatorNativeMethodName.stopFloatingPlayer.name,
    );
    return result;
  }
}
