class AndroidFontInfo {
  /// Whether to use a custom font. Default is false.
  final bool? isCustom;

  /// The Android system typeface name, such as "DEFAULT", "DEFAULT_BOLD", "SANS_SERIF", "SERIF", "MONOSPACE".
  /// Or custom font name, such as: "fonts/kaushanscript_regular.ttf". (You need to set the isCustom=true and put the font file in the "assets" directory: app/src/main/assets/fonts/kaushanscript_regular.ttf)
  final String? typefaceName;

  AndroidFontInfo({
    this.isCustom,
    this.typefaceName,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is AndroidFontInfo) {
      return isCustom == other.isCustom && typefaceName == other.typefaceName;
    }

    return false;
  }

  @override
  int get hashCode => isCustom.hashCode ^ typefaceName.hashCode;

  AndroidFontInfo deepCopy() => AndroidFontInfo(
        isCustom: isCustom,
        typefaceName: typefaceName,
      );
}
