import 'video_feed_source.dart';

class FeedItemDetails {
  /// The index of the thumbnail tapped in the feed.
  int? index;

  /// The unique id of the thumbnail.
  ///
  /// If the source is `playlistGroup` this value will represent the playlist's id; otherwise this value is the id of the selected video
  String id;

  /// The total duration of the video.
  ///
  /// If the source is `playlistGroup` this value will always be 0.
  /// Otherwise this value is the duration of the selected video.
  double? duration;

  /// The title of the feed item.
  ///
  /// Currently, the property doesn't have value on the Android side when the source is `playlistGroup`.
  /// But the property has value for other feed sources.
  String? title;

  /// The content source of the feed.
  VideoFeedSource source;

  /// The channel id of the feed.
  ///
  /// The property has value when the source is `channel` or `playlist` or `dynamicContent`.
  String? channel;

  /// Playlist id of the feed.
  ///
  /// The property has value when the source is `playlist`.
  String? playlist;

  /// Playlist group id of the feed.
  ///
  /// The property has value when the source is `playlistGroup`.
  String? playlistGroup;

  /// The dynamic content parameters of the feed.
  ///
  /// The property has value when the source is `dynamicContent`.
  Map<String, List<String>>? dynamicContentParameters;

  /// Hashtag filter expression is an s-expression used to provide feeds filtered by hashtags with specified criteria.
  /// Queries are specified with boolean predicates on what hashtags are there on the video.
  /// For instance, (and sport food) (or sport food) (and sport (or food comedy)) sport are all valid expressions.
  /// Non-UTF-8 characters are not allowed. If using boolean predicates, the expression needs to be wrapped with parenthesis.
  String? hashtagFilterExpression;

  FeedItemDetails({
    this.index,
    required this.id,
    this.duration,
    this.title,
    required this.source,
    this.channel,
    this.playlist,
    this.playlistGroup,
    this.dynamicContentParameters,
    this.hashtagFilterExpression,
  });
}
