import 'package:fw_flutter_sdk/src/models/method_names.dart';

import '../../models/fw_events.dart';
import '../../models/video_playback_details.dart';
import '../fw_method_channel_util.dart';
import 'feed_item_details_util.dart';
import 'fw_error_util.dart';
import 'live_stream_event_details_util.dart';
import 'live_stream_message_details_util.dart';
import 'shopping_cta_result_util.dart';
import 'video_playback_details_util.dart';

class SDKInitEventUtil {
  static SDKInitEvent? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      final errorJson = json["error"];
      return SDKInitEvent(
        error: FWErrorUtil.fromJson(
          errorJson,
        ),
      );
    }
    return null;
  }
}

class CustomCTAClickEventUtil {
  static CustomCTAClickEvent? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      if (json["url"] is String) {
        final event = CustomCTAClickEvent(url: json["url"] as String);

        if (json["callbackId"] is String) {
          final callbackId = json["callbackId"] as String;
          final playerHandler = PlayerHandler(
            pause: () {
              FWMethodChannelUtil.getFirewokSDKChannel().invokeMethod(
                FireworkSDKNativeMethodName.pausePlayer.name,
                callbackId,
              );
            },
            resume: () {
              FWMethodChannelUtil.getFirewokSDKChannel().invokeMethod(
                FireworkSDKNativeMethodName.resumePlayer.name,
                callbackId,
              );
            },
          );
          event.playerHandler = playerHandler;
        }

        return event;
      }
    }

    return null;
  }
}

class VideoPlaybackEventUtil {
  static VideoPlaybackEvent? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      if (json["eventName"] is String) {
        final eventName = VideoPlaybackDetailsUtil.createVideoPlaybackEventName(
            json["eventName"] as String);
        final info = VideoPlaybackDetailsUtil.fromJson(json["info"]);

        if (eventName != null && info != null) {
          return VideoPlaybackEvent(
            eventName: eventName,
            info: info,
          );
        }
      }
    }

    return null;
  }
}

class VideoFeedClickEventUtil {
  static VideoFeedClickEvent? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      final info = FeedItemDetailsUtil.fromJson(json["info"]);

      if (info != null) {
        return VideoFeedClickEvent(info: info);
      }
    }

    return null;
  }
}

class ShoppingCTAEventUtil {
  static ShoppingCTAEvent? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      ShoppingCTAEvent event = ShoppingCTAEvent();
      if (json["productId"] is String) {
        event.productId = json["productId"] as String;
      }

      if (json["unitId"] is String) {
        event.unitId = json["unitId"] as String;
      }

      if (json["url"] is String) {
        event.url = json["url"] as String;
      }

      if (json["callbackId"] is String) {
        final callbackId = json["callbackId"] as String;
        final ctaHandler = ShoppingCTAHandler(
          showLoader: () async {
            FWMethodChannelUtil.getShoppingChannel().invokeMethod(
              ShoppingNativeMethodName.showShoppingCTALoader.name,
              <String, dynamic>{
                "callbackId": callbackId,
              },
            );
          },
          complete: (result) async {
            final resultJson = ShoppingCTAResultUtil.toJson(result);
            FWMethodChannelUtil.getShoppingChannel().invokeMethod(
              ShoppingNativeMethodName.completeShoppingCTAHandlingProcess.name,
              <String, dynamic>{
                "callbackId": callbackId,
                "result": resultJson,
              },
            );
          },
        );
        event.ctaHandler = ctaHandler;
      }

      return event;
    }

    return ShoppingCTAEvent();
  }
}

class UpdateProductDetailsEventUtil {
  static UpdateProductDetailsEvent? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      if (json["productIds"] is List<dynamic>) {
        final productIds = json["productIds"] as List<dynamic>;
        List<String> resultProductIds = [];
        for (var element in productIds) {
          if (element is String) {
            resultProductIds.add(element);
          }
        }

        return UpdateProductDetailsEvent(
          productIds: resultProductIds,
        );
      }
    }

    return null;
  }
}

class CustomClickLinkButtonEventUtil {
  static CustomClickLinkButtonEvent? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      CustomClickLinkButtonEvent event = CustomClickLinkButtonEvent();
      if (json["productId"] is String) {
        event.productId = json["productId"] as String;
      }

      if (json["unitId"] is String) {
        event.unitId = json["unitId"] as String;
      }

      if (json["url"] is String) {
        event.url = json["url"] as String;
      }

      return event;
    }

    return null;
  }
}

class CustomTapProductCardEventUtil {
  static CustomTapProductCardEvent? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      final video = VideoPlaybackDetailsUtil.fromJson(json["video"]) ??
          VideoPlaybackDetails(videoId: "");
      CustomTapProductCardEvent event = CustomTapProductCardEvent(video: video);
      if (json["productId"] is String) {
        event.productId = json["productId"] as String;
      }

      if (json["unitId"] is String) {
        event.unitId = json["unitId"] as String;
      }

      if (json["url"] is String) {
        event.url = json["url"] as String;
      }

      return event;
    }

    return null;
  }
}

class LiveStreamEventUtil {
  static LiveStreamEvent? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      if (json["eventName"] is String) {
        final eventName = LiveStreamEventDetailsUtil.createLiveStreamEventName(
            json["eventName"] as String);
        final info = LiveStreamEventDetailsUtil.fromJson(json["info"]);

        if (eventName != null && info != null) {
          return LiveStreamEvent(
            eventName: eventName,
            info: info,
          );
        }
      }
    }

    return null;
  }
}

class LiveStreamChatEventUtil {
  static LiveStreamChatEvent? fromJson(dynamic json) {
    if (json is Map<dynamic, dynamic>) {
      if (json["eventName"] is String) {
        final eventName =
            LiveStreamMessageDetailsUtil.createLiveStreamChatEventName(
                json["eventName"] as String);
        final message = LiveStreamMessageDetailsUtil.fromJson(json["message"]);
        final liveStream =
            LiveStreamEventDetailsUtil.fromJson(json["liveStream"]);

        if (eventName != null && message != null && liveStream != null) {
          return LiveStreamChatEvent(
            eventName: eventName,
            message: message,
            liveStream: liveStream,
          );
        }
      }
    }

    return null;
  }
}
