import 'package:flutter_test/flutter_test.dart';
import 'package:fw_flutter_sdk/src/models/button_info.dart';
import 'package:fw_flutter_sdk/src/models/ios_font_info.dart';
import 'package:fw_flutter_sdk/src/models/story_block_configuration.dart';
import 'package:fw_flutter_sdk/src/models/story_block_native_configuration.dart';
import 'package:fw_flutter_sdk/src/models/video_player_button_configuration.dart';
import 'package:fw_flutter_sdk/src/models/video_player_complete_action.dart';
import 'package:fw_flutter_sdk/src/models/video_player_cta_delay.dart';
import 'package:fw_flutter_sdk/src/models/video_player_cta_style.dart';
import 'package:fw_flutter_sdk/src/models/video_player_cta_width.dart';
import 'package:fw_flutter_sdk/src/models/video_player_logo_configuration.dart';
import 'package:fw_flutter_sdk/src/models/video_player_style.dart';
import 'package:fw_flutter_sdk/src/utils/model_utils/story_block_configuration_util.dart';

void main() {
  test('StoryBlockConfigurationUtil toJson', () {
    final configuration = StoryBlockConfiguration(
      playerStyle: VideoPlayerStyle.fit,
      videoCompleteAction: VideoPlayerCompleteAction.advanceToNext,
      showShareButton: true,
      ctaButtonStyle: VideoPlayerCTAStyle(
        backgroundColor: "#c0c0c0",
        textColor: "#000000",
        fontSize: 16,
        iOSFontInfo: IOSFontInfo(
          fontName: "Helvetica",
          systemFontStyle: IOSSystemFontStyle.italic,
          systemFontWeight: IOSSystemFontWeight.heavy,
        ),
      ),
      showPlaybackButton: true,
      showMuteButton: true,
      showBranding: true,
      ctaDelay: VideoPlayerCTADelay(
        type: VideoPlayerCTADelayType.constant,
        value: 3,
      ),
      shareBaseURL: "test_share_url",
      ctaWidth: VideoPlayerCTAWidth.fullWidth,
      buttonConfiguration: VideoPlayerButtonConfiguration(
        videoDetailButton: ButtonInfo(
          imageName: 'custom_more',
        ),
        closeButton: ButtonInfo(imageName: 'custom_close'),
        muteButton: ButtonInfo(imageName: 'custom_mute'),
        unmuteButton: ButtonInfo(imageName: 'custom_unmute'),
        playButton: ButtonInfo(imageName: 'custom_play'),
        pauseButton: ButtonInfo(imageName: 'custom_pause'),
      ),
      videoPlayerLogoConfiguration: VideoPlayerLogoConfiguration(
        option: VideoPlayerLogoOption.channelAggregator,
        encodedId: 'test_encoded_id',
      ),
      showVideoDetailTitle: true,
    );
    final json = StoryBlockConfigurationUtil.toJson(configuration);

    expect(json["playerStyle"], configuration.playerStyle?.name);
    expect(
        json["videoCompleteAction"], configuration.videoCompleteAction?.name);
    expect(json["showShareButton"], configuration.showShareButton);
    expect(json["ctaButtonStyle"] is Map<String, dynamic>, true);
    final ctaButtonStyleJson = json["ctaButtonStyle"] as Map<String, dynamic>;
    expect(ctaButtonStyleJson["backgroundColor"],
        configuration.ctaButtonStyle?.backgroundColor);
    expect(ctaButtonStyleJson["textColor"],
        configuration.ctaButtonStyle?.textColor);
    expect(
        ctaButtonStyleJson["fontSize"], configuration.ctaButtonStyle?.fontSize);
    expect(ctaButtonStyleJson["iOSFontInfo"]["fontName"],
        configuration.ctaButtonStyle?.iOSFontInfo?.fontName);
    expect(ctaButtonStyleJson["iOSFontInfo"]["systemFontStyle"],
        configuration.ctaButtonStyle?.iOSFontInfo?.systemFontStyle?.name);
    expect(ctaButtonStyleJson["iOSFontInfo"]["systemFontWeight"],
        configuration.ctaButtonStyle?.iOSFontInfo?.systemFontWeight?.name);
    expect(json["showPlaybackButton"], configuration.showPlaybackButton);
    expect(json["showMuteButton"], configuration.showMuteButton);
    expect(json["showBranding"], configuration.showBranding);

    expect(json["ctaDelay"]["type"], configuration.ctaDelay?.type.name);
    expect(json["ctaDelay"]["value"], configuration.ctaDelay?.value);
    expect(json["shareBaseURL"], configuration.shareBaseURL);
    expect(json["ctaWidth"], configuration.ctaWidth?.name);

    final buttonConfigurationJson =
        json["buttonConfiguration"] as Map<String, dynamic>;
    expect(
        (buttonConfigurationJson["videoDetailButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_more");
    expect(
        (buttonConfigurationJson["closeButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_close");
    expect(
        (buttonConfigurationJson["muteButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_mute");
    expect(
        (buttonConfigurationJson["unmuteButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_unmute");
    expect(
        (buttonConfigurationJson["playButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_play");
    expect(
        (buttonConfigurationJson["pauseButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_pause");

    final videoPlayerLogoConfigurationJson =
        json["videoPlayerLogoConfiguration"] as Map<String, dynamic>;
    expect(videoPlayerLogoConfigurationJson["option"],
        configuration.videoPlayerLogoConfiguration?.option.name);
    expect(videoPlayerLogoConfigurationJson["encodedId"],
        configuration.videoPlayerLogoConfiguration?.encodedId);

    expect(json["showVideoDetailTitle"], configuration.showVideoDetailTitle);
  });

  test('StoryBlockConfigurationUtil toJson for StoryBlockNativeConfiguration',
      () {
    final configuration = StoryBlockNativeConfiguration(
      playerStyle: VideoPlayerStyle.fit,
      videoCompleteAction: VideoPlayerCompleteAction.advanceToNext,
      showShareButton: true,
      ctaButtonStyle: VideoPlayerCTAStyle(
        backgroundColor: "#c0c0c0",
        textColor: "#000000",
        fontSize: 16,
        iOSFontInfo: IOSFontInfo(
          fontName: "Helvetica",
          systemFontStyle: IOSSystemFontStyle.italic,
          systemFontWeight: IOSSystemFontWeight.heavy,
        ),
      ),
      showPlaybackButton: true,
      showMuteButton: true,
      showBranding: true,
      ctaDelay: VideoPlayerCTADelay(
        type: VideoPlayerCTADelayType.constant,
        value: 3,
      ),
      shareBaseURL: "test_share_url",
      ctaWidth: VideoPlayerCTAWidth.fullWidth,
      enablePictureInPicture: true,
      buttonConfiguration: VideoPlayerButtonConfiguration(
        videoDetailButton: ButtonInfo(
          imageName: 'custom_more',
        ),
        closeButton: ButtonInfo(imageName: 'custom_close'),
        muteButton: ButtonInfo(imageName: 'custom_mute'),
        unmuteButton: ButtonInfo(imageName: 'custom_unmute'),
        playButton: ButtonInfo(imageName: 'custom_play'),
        pauseButton: ButtonInfo(imageName: 'custom_pause'),
      ),
      videoPlayerLogoConfiguration: VideoPlayerLogoConfiguration(
        option: VideoPlayerLogoOption.channelAggregator,
        encodedId: 'test_encoded_id',
      ),
      showVideoDetailTitle: true,
    );
    final json = StoryBlockConfigurationUtil.toJson(configuration);
    expect(json["playerStyle"], configuration.playerStyle?.name);
    expect(
        json["videoCompleteAction"], configuration.videoCompleteAction?.name);
    expect(json["showShareButton"], configuration.showShareButton);
    expect(json["ctaButtonStyle"] is Map<String, dynamic>, true);
    final ctaButtonStyleJson = json["ctaButtonStyle"] as Map<String, dynamic>;
    expect(ctaButtonStyleJson["backgroundColor"],
        configuration.ctaButtonStyle?.backgroundColor);
    expect(ctaButtonStyleJson["textColor"],
        configuration.ctaButtonStyle?.textColor);
    expect(
        ctaButtonStyleJson["fontSize"], configuration.ctaButtonStyle?.fontSize);
    expect(ctaButtonStyleJson["iOSFontInfo"]["fontName"],
        configuration.ctaButtonStyle?.iOSFontInfo?.fontName);
    expect(ctaButtonStyleJson["iOSFontInfo"]["systemFontStyle"],
        configuration.ctaButtonStyle?.iOSFontInfo?.systemFontStyle?.name);
    expect(ctaButtonStyleJson["iOSFontInfo"]["systemFontWeight"],
        configuration.ctaButtonStyle?.iOSFontInfo?.systemFontWeight?.name);
    expect(json["showPlaybackButton"], configuration.showPlaybackButton);
    expect(json["showBranding"], configuration.showBranding);
    expect(json["showPlaybackButton"], configuration.showPlaybackButton);
    expect(json["showMuteButton"], configuration.showMuteButton);

    expect(json["ctaDelay"]["type"], configuration.ctaDelay?.type.name);
    expect(json["ctaDelay"]["value"], configuration.ctaDelay?.value);
    expect(json["shareBaseURL"], configuration.shareBaseURL);
    expect(json["ctaWidth"], configuration.ctaWidth?.name);
    expect(
        json["enablePictureInPicture"], configuration.enablePictureInPicture);
    final buttonConfigurationJson =
        json["buttonConfiguration"] as Map<String, dynamic>;
    expect(
        (buttonConfigurationJson["videoDetailButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_more");
    expect(
        (buttonConfigurationJson["closeButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_close");
    expect(
        (buttonConfigurationJson["muteButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_mute");
    expect(
        (buttonConfigurationJson["unmuteButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_unmute");
    expect(
        (buttonConfigurationJson["playButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_play");
    expect(
        (buttonConfigurationJson["pauseButton"]
            as Map<String, dynamic>)["imageName"],
        "custom_pause");

    final videoPlayerLogoConfigurationJson =
        json["videoPlayerLogoConfiguration"] as Map<String, dynamic>;
    expect(videoPlayerLogoConfigurationJson["option"],
        configuration.videoPlayerLogoConfiguration?.option.name);
    expect(videoPlayerLogoConfigurationJson["encodedId"],
        configuration.videoPlayerLogoConfiguration?.encodedId);

    expect(json["showVideoDetailTitle"], configuration.showVideoDetailTitle);
  });
}
